@@ -93,6 +93,7 @@ describe 'horizon' do
       before do
         params.merge!({
           :purge_conf_d_dir                 => true,
+          :memoized_max_size_default        => 25,
           :cache_backend                    => 'django.core.cache.backends.memcached.MemcachedCache',
           :cache_timeout                    => 300,
           :cache_options                    => {'SOCKET_TIMEOUT' => 1,'SERVER_RETRIES' => 1,'DEAD_RETRY' => 1},
@@ -113,6 +114,7 @@ describe 'horizon' do
           :dropdown_max_items               => 123,
           :compress_enabled                 => false,
           :compress_offline                 => false,
+          :compress_root                    => '/tmp',
           :hypervisor_options               => {'can_set_mount_point' => false, 'can_set_password' => true },
           :cinder_options                   => {'enable_backup' => true },
           :keystone_options                 => {'name' => 'native', 'can_edit_user' => true, 'can_edit_group' => true, 'can_edit_project' => true, 'can_edit_domain' => false, 'can_edit_role' => false},
@@ -128,6 +130,7 @@ describe 'horizon' do
           :keystone_default_domain          => 'domain.tld',
           :overview_days_range              => 1,
           :session_timeout                  => 1800,
+          :simultaneous_sessions            => 'allow',
           :token_timeout_margin             => 60,
           :timezone                         => 'Asia/Shanghai',
           :available_themes                 => [
@@ -140,9 +143,19 @@ describe 'horizon' do
           :password_retrieve                => true,
           :enable_secure_proxy_ssl_header   => true,
           :secure_proxy_addr_header         => 'HTTP_X_FORWARDED_FOR',
+          :show_diff                        => true,
         })
       end
 
+      it {
+        is_expected.to contain_concat(platforms_params[:config_file]).with(
+          :mode      => '0640',
+          :owner     => platforms_params[:wsgi_user],
+          :group     => platforms_params[:wsgi_group],
+          :show_diff => true,
+        )
+      }
+
       it 'generates local_settings.py' do
         verify_concat_fragment_contents(catalogue, 'local_settings.py', [
           'DEBUG = True',
@@ -161,6 +174,7 @@ describe 'horizon' do
           "            'DEAD_RETRY': 1,",
           "            'SERVER_RETRIES': 1,",
           "            'SOCKET_TIMEOUT': 1,",
+          "MEMOIZED_MAX_SIZE_DEFAULT = 25",
           "        'BACKEND': 'django.core.cache.backends.memcached.MemcachedCache',",
           "        'LOCATION': '10.0.0.1:11211',",
           "        'TIMEOUT': 300,",
@@ -216,9 +230,11 @@ describe 'horizon' do
           "            'level': 'DEBUG',",
           "            'handlers': ['console', 'syslog'],",
           'SESSION_TIMEOUT = 1800',
+          "SIMULTANEOUS_SESSIONS = 'allow'",
           'TOKEN_TIMEOUT_MARGIN = 60',
           'COMPRESS_ENABLED = False',
           'COMPRESS_OFFLINE = False',
+          "COMPRESS_ROOT = '/tmp'",
           "FILE_UPLOAD_TEMP_DIR = '/var/spool/horizon'",
           'OVERVIEW_DAYS_RANGE = 1',
           'DISALLOW_IFRAME_EMBED = True',
@@ -364,6 +380,32 @@ describe 'horizon' do
       it { is_expected.not_to contain_package('python-pymemcache') }
     end
 
+    context 'installs python redis library when cache_backend is set to redis' do
+      before do
+        params.merge!({
+          :cache_backend => 'django.core.cache.backends.redis.RedisCache',
+        })
+      end
+
+      it {
+        is_expected.to contain_package('python-redis').with(
+          :tag    => ['openstack'],
+          :name   => platforms_params[:python_redis_package],
+        )
+      }
+    end
+
+    context 'does not install python redis when manage_memcache_package set to false' do
+      before do
+        params.merge!({
+          :cache_backend           => 'django.core.cache.backends.redis.RedisCache',
+          :manage_memcache_package => false
+        })
+      end
+
+      it { is_expected.not_to contain_package('python-redis') }
+    end
+
     context 'with custom wsgi options' do
       before do
         params.merge!( :wsgi_processes    => '30',
@@ -703,6 +745,23 @@ describe 'horizon' do
       end
     end
 
+    context 'with horizon_app_links' do
+      before do
+        params.merge!({
+          :horizon_app_links => [
+            'https://monitoring1.example.com',
+            'https://monitoring2.example.com'
+          ]
+        })
+      end
+
+      it 'configures EXTERNAL_MONITORING' do
+        verify_concat_fragment_contents(catalogue, 'local_settings.py', [
+          "EXTERNAL_MONITORING = ['https://monitoring1.example.com', 'https://monitoring2.example.com']",
+        ])
+      end
+    end
+
     context 'with help_url, bug_url and customization_module provided' do
       before do
         params.merge!({
@@ -795,41 +854,44 @@ describe 'horizon' do
         case facts[:os]['family']
         when 'Debian'
           if facts[:os]['name'] == 'Debian'
-            { :config_file        => '/etc/openstack-dashboard/local_settings.py',
-              :conf_d_dir         => '/etc/openstack-dashboard/local_settings.d',
-              :secret_key_file    => '/etc/openstack-dashboard/.secret_key_store',
-              :package_name       => 'openstack-dashboard-apache',
-              :root_url           => '/horizon',
-              :root_path          => '/var/lib/openstack-dashboard',
-              :memcache_package   => 'python3-memcache',
-              :pymemcache_package => 'python3-pymemcache',
-              :wsgi_user          => 'horizon',
-              :wsgi_group         => 'horizon',
+            { :config_file          => '/etc/openstack-dashboard/local_settings.py',
+              :conf_d_dir           => '/etc/openstack-dashboard/local_settings.d',
+              :secret_key_file      => '/etc/openstack-dashboard/.secret_key_store',
+              :package_name         => 'openstack-dashboard-apache',
+              :root_url             => '/horizon',
+              :root_path            => '/var/lib/openstack-dashboard',
+              :memcache_package     => 'python3-memcache',
+              :pymemcache_package   => 'python3-pymemcache',
+              :python_redis_package => 'python3-redis',
+              :wsgi_user            => 'horizon',
+              :wsgi_group           => 'horizon',
             }
           else
-            { :config_file        => '/etc/openstack-dashboard/local_settings.py',
-              :conf_d_dir         => '/etc/openstack-dashboard/local_settings.d',
-              :secret_key_file    => '/etc/openstack-dashboard/.secret_key_store',
-              :package_name       => 'openstack-dashboard',
-              :root_url           => '/horizon',
-              :root_path          => '/var/lib/openstack-dashboard',
-              :memcache_package   => 'python3-memcache',
-              :pymemcache_package => 'python3-pymemcache',
-              :wsgi_user          => 'horizon',
-              :wsgi_group         => 'horizon',
+            { :config_file          => '/etc/openstack-dashboard/local_settings.py',
+              :conf_d_dir           => '/etc/openstack-dashboard/local_settings.d',
+              :secret_key_file      => '/etc/openstack-dashboard/.secret_key_store',
+              :package_name         => 'openstack-dashboard',
+              :root_url             => '/horizon',
+              :root_path            => '/var/lib/openstack-dashboard',
+              :memcache_package     => 'python3-memcache',
+              :pymemcache_package   => 'python3-pymemcache',
+              :python_redis_package => 'python3-redis',
+              :wsgi_user            => 'horizon',
+              :wsgi_group           => 'horizon',
             }
           end
         when 'RedHat'
-          { :config_file        => '/etc/openstack-dashboard/local_settings',
-            :conf_d_dir         => '/etc/openstack-dashboard/local_settings.d',
-            :secret_key_file    => '/etc/openstack-dashboard/.secret_key_store',
-            :package_name       => 'openstack-dashboard',
-            :root_url           => '/dashboard',
-            :root_path          => '/usr/share/openstack-dashboard',
-            :memcache_package   => 'python3-memcached',
-            :pymemcache_package => 'python3-pymemcache',
-            :wsgi_user          => 'apache',
-            :wsgi_group         => 'apache',
+          { :config_file          => '/etc/openstack-dashboard/local_settings',
+            :conf_d_dir           => '/etc/openstack-dashboard/local_settings.d',
+            :secret_key_file      => '/etc/openstack-dashboard/.secret_key_store',
+            :package_name         => 'openstack-dashboard',
+            :root_url             => '/dashboard',
+            :root_path            => '/usr/share/openstack-dashboard',
+            :memcache_package     => 'python3-memcached',
+            :pymemcache_package   => 'python3-pymemcache',
+            :python_redis_package => 'python3-redis',
+            :wsgi_user            => 'apache',
+            :wsgi_group           => 'apache',
           }
         end
       end
